@@ -1,12 +1,12 @@
 #!/usr/bin/env r
 
 ## configuration for docopt
-doc <- "Usage: dequeueJobs.r [-q QUEUE] [-e EXCP] [-h] [-x] PACKAGE
+doc <- paste0("Usage: dequeueJobs.r [-q QUEUE] [-e EXCP] [-h] [-x] PACKAGE
 
--q --queue QUEUE      set queue directory [default: .]
+-q --queue QUEUE      set queue directory [default: ", getOption("prrd.queue_directory", "."), "]
 -e --exclude EXCL     exclusion set filename [default: ]
 -h --help             show this help text
--x --usage            show help and short example usage"
+-x --usage            show help and short example usage")
 
 opt <- docopt::docopt(doc)              # docopt parsing
 
@@ -16,7 +16,7 @@ if (opt$usage) {
   dequeueJobs.r
 
 dequeueJobs.r is part of prrd.r which is becoming a parallel rev dep runner.
-See http://dirk.eddelbuettel.com/code/...TBD.... for more information.\n")
+See http://dirk.eddelbuettel.com/code/prrd.html for more information.\n")
     q("no")
 }
 
